#import radiopropa
from __future__ import absolute_import, division, print_function
#import radiopropa
import argparse
# import detector simulation modules
import NuRadioReco.modules.trigger.highLowThreshold
import NuRadioReco.modules.trigger.simpleThreshold
import NuRadioReco.modules.channelBandPassFilter
import NuRadioReco.modules.RNO_G.hardwareResponseIncorporator
from NuRadioReco.utilities import units
from NuRadioMC.simulation import simulation
import logging
import os
logging.basicConfig(level=logging.WARNING)
logger = logging.getLogger("runstrawman")

# initialize detector sim modules
simpleThreshold = NuRadioReco.modules.trigger.simpleThreshold.triggerSimulator()
highLowThreshold = NuRadioReco.modules.trigger.highLowThreshold.triggerSimulator()
channelBandPassFilter = NuRadioReco.modules.channelBandPassFilter.channelBandPassFilter()
hardware_response = NuRadioReco.modules.RNO_G.hardwareResponseIncorporator.hardwareResponseIncorporator()

class mySimulation(simulation.simulation):
   
    def _detector_simulation_filter_amp(self, evt, station, det):
        if 1:#evt.get_run_number() == 140:
            hardware_response.run(evt, station, det, sim_to_data=True)

    #    print("evt id", evt.get_run_number())
    def _detector_simulation_trigger(self, evt, station, det):
        # first run a simple threshold trigger
        # run a high/low trigger on the 4 downward pointing LPDAs
        if 1:
           
            highLowThreshold.run(evt, station, det,
                                    threshold_high=23.4 * units.mV,
                                    threshold_low=-23.4 * units.mV,
                                    triggered_channels=[0], 
                                    number_concidences=1,  
                                    trigger_name='main_trigger'
                             )



parser = argparse.ArgumentParser(description='Run NuRadioMC simulation')
parser.add_argument('input_dir', type=str)
parser.add_argument('output_dir', type=str)
parser.add_argument('number', type=int)

args = parser.parse_args()

input_dir = args.input_dir
output_dir = args.output_dir
number = args.number

filenames = sorted(os.listdir(input_dir))
filename = os.path.join(input_dir, filenames[number])
    
filename_hdf5 = 'event_{:04d}.hdf5'.format(number)
filename_nuradioreco = 'event_{:04d}.nur'.format(number)

sim = mySimulation(
    inputfilename=filename,
    outputfilename=os.path.join(output_dir, filename_hdf5),
    detectorfile='./station_RNOG.json',
    outputfilenameNuRadioReco=os.path.join(output_dir, filename_nuradioreco),
    config_file='./config_RNOG.yaml',
    file_overwrite=True,
    write_detector=False,
    default_detector_channel=0,
    default_detector_station=101
)
sim.run()
logger.warning(f"finished {number}")
